summaryrefslogtreecommitdiffstats
path: root/buildtools/lib/parsers/qmake/qmake_yacc.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'buildtools/lib/parsers/qmake/qmake_yacc.cpp')
-rw-r--r--buildtools/lib/parsers/qmake/qmake_yacc.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/buildtools/lib/parsers/qmake/qmake_yacc.cpp b/buildtools/lib/parsers/qmake/qmake_yacc.cpp
index 32722979..718cb4f5 100644
--- a/buildtools/lib/parsers/qmake/qmake_yacc.cpp
+++ b/buildtools/lib/parsers/qmake/qmake_yacc.cpp
@@ -19,7 +19,7 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA. */
/* As a special exception, you may create a larger work that contains
part or all of the Bison parser skeleton and distribute that work
under terms of your choice, so long as that work isn't itself a
parser generator using the skeleton or a modified version thereof
@@ -33,7 +33,7 @@
version 2.2 of Bison. */
// Take the name prefix into account.
-#define yylex QMakelex
+#define yylex TQMakelex
#include "qmake_yacc.hpp"
@@ -41,7 +41,7 @@
/* Line 317 of lalr1.cc. */
-#line 45 "qmake_yacc.cpp"
+#line 45 "tqmake_yacc.cpp"
#ifndef YY_
# if YYENABLE_NLS
@@ -100,7 +100,7 @@ do { \
#define YYABORT goto yyabortlab
#define YYERROR goto yyerrorlab
-namespace QMake
+namespace TQMake
{
#if YYERROR_VERBOSE
@@ -144,7 +144,7 @@ namespace QMake
#endif
/// Build a parser object.
- Parser::Parser (QMake::Lexer* lexer_yyarg, TQValueStack<ProjectAST*>& projects_yyarg, int depth_yyarg)
+ Parser::Parser (TQMake::Lexer* lexer_yyarg, TQValueStack<ProjectAST*>& projects_yyarg, int depth_yyarg)
: yydebug_ (false),
yycdebug_ (&std::cerr),
lexer (lexer_yyarg),
@@ -679,7 +679,7 @@ namespace QMake
depth++;
//qWarning("%s", $<value>1.ascii());
- if ((yysemantic_stack_[(4) - (1)].value).contains("include"))
+ if ((yysemantic_stack_[(4) - (1)].value).tqcontains("include"))
{
IncludeAST *includeAST = new IncludeAST();
includeAST->projectName = (yysemantic_stack_[(4) - (3)].value);
@@ -752,7 +752,7 @@ namespace QMake
/* Line 675 of lalr1.cc. */
-#line 756 "qmake_yacc.cpp"
+#line 756 "tqmake_yacc.cpp"
default: break;
}
YY_SYMBOL_PRINT ("-> $$ =", yyr1_[yyn], &yyval, &yyloc);
@@ -1089,7 +1089,7 @@ namespace QMake
"$end", "error", "$undefined", "ID_SIMPLE", "EQ", "PLUSEQ", "MINUSEQ",
"STAREQ", "TILDEEQ", "LBRACE", "RBRACE", "COLON", "NEWLINE", "COMMENT",
"CONT", "COMMENT_CONT", "RCURLY", "LCURLY", "ID_ARGS",
- "QUOTED_VARIABLE_VALUE", "VARIABLE_VALUE", "LIST_WS", "ENDOFFILE",
+ "TQUOTED_VARIABLE_VALUE", "VARIABLE_VALUE", "LIST_WS", "ENDOFFILE",
"\"else\"", "$accept", "project", "@1", "statements", "statement",
"variable_assignment", "possible_value", "multiline_values",
"variable_value", "listws", "operator", "scope", "@2", "function_call",
@@ -1227,13 +1227,13 @@ namespace QMake
const unsigned int Parser::yyuser_token_number_max_ = 278;
const Parser::token_number_type Parser::yyundef_token_ = 2;
-} // namespace QMake
+} // namespace TQMake
#line 421 "qmake.yy"
-namespace QMake
+namespace TQMake
{
void Parser::error(const location_type& /*l*/, const std::string& m)
{
@@ -19,7 +19,7 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA. */
-/* As a special exception, you may create a larger work that contains
+/* As a special exception, you may create a larger work that tqcontains
part or all of the Bison parser skeleton and distribute that work
under terms of your choice, so long as that work isn't itself a